.. _containers:

=========================
Containers (`containers`)
=========================

.. currentmodule:: ctapipe.containers

Introduction
============

Contains the data model definition of all ctapipe `Container` classes.

The base Container for an event is in `ctapipe.containers.DataContainer`. 

        
Reference/API
=============

.. automodapi:: ctapipe.containers

